Module request_hook

Module request_hook 

Hooks for horizontal functionality that can run either before or after a request is executed.

Structs

BeforeRequestCons
A list of hooks that run in order before a request is executed.
BeforeRequestNil
A noop hook that runs before a request is executed.
HookThenServe
A Service function that runs a hook before request execution.
HookThenServeThenHook
A Service function that runs a hook both before and after request execution.
ServeThenHook
A Service function that runs a hook after request execution.

Traits

AfterRequest
A hook that runs after request execution.
BeforeRequest
A hook that runs before request execution.
BeforeRequestList
A list of hooks that run in order before request execution.
RequestHook
Hooks that run before and/or after serving a request.

Functions

before
Returns a request hook builder that runs a series of hooks before request execution.