Hooks for horizontal functionality that can run either before or after a request is executed.
Structs
- Before
Request Cons - A list of hooks that run in order before a request is executed.
- Before
Request Nil - A noop hook that runs before a request is executed.
- Hook
Then Serve - A Service function that runs a hook before request execution.
- Hook
Then Serve Then Hook - A Service function that runs a hook both before and after request execution.
- Serve
Then Hook - A Service function that runs a hook after request execution.
Traits
- After
Request - A hook that runs after request execution.
- Before
Request - A hook that runs before request execution.
- Before
Request List - A list of hooks that run in order before request execution.
- Request
Hook - Hooks that run before and/or after serving a request.
Functions
- before
- Returns a request hook builder that runs a series of hooks before request execution.